@@ -84,34 +84,12 @@ class ImageModelTraining:
 
     def train_model(self, model, criterion, optimizer):
         train_loss, evaluate_accuracy = 0, 0
-        for epoch in range(self.num_epochs):
-            print(f"Epoch {epoch + 1}/{self.num_epochs}")
-            running_loss = 0.0
-            with tqdm(total=len(self.train_loader)) as progress_bar:
-                for i, (inputs, labels) in enumerate(self.train_loader, 0):
-                    optimizer.zero_grad()
-
-                    inputs, labels = inputs.to(self.device), labels.to(self.device)
-
-                    try:
-                        outputs = model(inputs.float())
-                    except Exception as e:
-                        print(f"Error while running model: {e}")
-                        print("Input size:", inputs.size())
-
-                    loss = criterion(outputs, labels)
-                    loss.backward()
-
-                    optimizer.step()
-
-                    running_loss += loss.item()
-                    progress_bar.update(1)
-                    progress_bar.set_description(f"Training loss: {running_loss / (i + 1):.4f}")
-
+        for epoch in tqdm(range(self.num_epochs)):
+            train_loss = self.train_model_epoch(model, self.train_loader, criterion, optimizer)
             evaluate_accuracy = self.evaluate_model(model=model, data_loader=self.val_loader, device=self.device)
-            print(
-                f"Train Loss: {running_loss / len(self.train_loader):.4f} - Evaluate Accuracy: {evaluate_accuracy:.4f}")
-        return running_loss / len(self.train_loader), evaluate_accuracy
+            tqdm.write(
+                f"Epoch {epoch + 1}/{self.num_epochs} - Train Loss: {train_loss:.4f} - Evaluate Accuracy: {evaluate_accuracy:.4f}")
+        return train_loss, evaluate_accuracy
 
     def train_model_epoch(self, model, dataloader, criterion, optimizer):
         running_loss = 0.0
